@@ -48,7 +48,7 @@ type testCase struct {
 const (
 	serviceMeshTestNamespaceName = "serverless-tests-mesh"
 	helloworldImage              = "gcr.io/knative-samples/helloworld-go"
-	httpProxyImage               = "registry.svc.ci.openshift.org/openshift/knative-v0.17.3:knative-serving-test-httpproxy"
+	httpProxyImage               = "registry.ci.openshift.org/openshift/knative-v0.17.3:knative-serving-test-httpproxy"
 	istioInjectKey               = "sidecar.istio.io/inject"
 )
 
@@ -601,7 +601,8 @@ func TestKsvcWithServiceMeshJWTDefaultPolicy(t *testing.T) {
 
 		// Create a test ksvc, should be accessible only via proper JWT token
 		testKsvc := test.Service("jwt-test", testNamespace, image, map[string]string{
-			"sidecar.istio.io/inject": "true",
+			"sidecar.istio.io/inject":                "true",
+			"sidecar.istio.io/rewriteAppHTTPProbers": "true",
 		})
 		testKsvc = withServiceReadyOrFail(ctx, testKsvc)
 
@@ -832,7 +833,7 @@ func TestKsvcWithServiceMeshCustomDomain(t *testing.T) {
 		}
 
 		// Poll, as it is expected OpenShift Router will return 503s until it reconciles the Route.
-		resp, err := sc.Poll(req, pkgTest.IsStatusOK)
+		resp, err := sc.Poll(req, spoof.IsStatusOK)
 		if err != nil {
 			t.Fatalf("Error polling custom domain: %v", err)
 		}
@@ -978,7 +979,7 @@ func TestKsvcWithServiceMeshCustomTlsDomain(t *testing.T) {
 		}
 
 		// Poll, as it is expected OpenShift Router will return 503s until it reconciles the Route.
-		resp, err := sc.Poll(req, pkgTest.IsStatusOK)
+		resp, err := sc.Poll(req, spoof.IsStatusOK)
 		if err != nil {
 			t.Fatalf("Error polling custom domain: %v", err)
 		}
